import { 
  			select, 
        csv, 
        scaleLinear, 
        extent, 
        scaleTime, 
        axisLeft,
  			axisBottom
} from "d3";

const svg = select("svg");

const width = +svg.attr("width");
const height = +svg.attr("height"); 

const render = data => {
  const title = "A Week in San Francisco";
  
  const xValue = d => d.timestamp;
  const xAxisLabel = "Time";
  
  const yValue = d => d.temperature;
  const yAxisLabel = "Temperature";
  
  const circleRadius = 6;
  const margin = { top: 75, right: 35, bottom:70, left: 90};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height -margin.top - margin.bottom;

  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  
  const xAxis = axisBottom(xScale)
      .tickSize(-innerHeight)
  		.tickPadding(15);
            
  const g = svg.append("g")
  		.attr("transform", `translate(${margin.left}, ${margin.top})`)
  
	const yAxis = axisLeft(yScale)
  		.tickSize(-innerWidth)
  		.tickPadding(10);
  
  const yAxisG = g.append("g").call(yAxis)
  yAxisG.selectAll(".domain").remove();
  
  yAxisG.append("text")
  			.attr("class", "axis-label")
  			.attr("x", -innerHeight / 2)
  			.attr("y", -50)
  			.attr("fill", "black")
  			.attr("transform", `rotate(-90)`)
  			.attr("text-anchor", "middle")
  			.text(yAxisLabel)
  
  const xAxisG = g.append("g").call(xAxis)
  	.attr("transform", `translate(0, ${innerHeight})`);
  
  
  xAxisG.select(".domain").remove();
  
	xAxisG.append("text")
  			.attr("class", "axis-label")
  			.attr("x", innerWidth/2)
  			.attr("y", 60)
  			.attr("fill", "black")
  			.text(xAxisLabel)
  
  
  
  g.selectAll("circle").data(data)
  	.enter().append("circle")
  		.attr("cx", d => xScale(xValue(d)))
  		.attr("cy", d => yScale(yValue(d)))
  		.attr("r", circleRadius);
  
  g.append("text")
  	.attr("class", "title")
  	.attr("y", -15)
  	.text(title);
}


csv("https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv")
  .then(data => {				
		data.forEach(d => {
  		d.temperature = +d.temperature;
			d.timestamp =new Date(d.timestamp);
  });
  render(data);
});
